## 每日停复牌信息

接口：suspend_d

更新时间：不定期

描述：按日期方式获取股票每日停复牌信息

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码(可输入多值) |
| trade_date | str | N | 交易日日期 |
| start_date | str | N | 停复牌查询开始日期 |
| end_date | str | N | 停复牌查询结束日期 |
| suspend_type | str | N | 停复牌类型：S-停牌,R-复牌 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS代码 |
| trade_date | str | Y | 停复牌日期 |
| suspend_timing | str | Y | 日内停牌时间段 |
| suspend_type | str | Y | 停复牌类型：S-停牌，R-复牌 |

接口用法

```python
pro = ts.pro_api()

#提取2020-03-12的停牌股票
df = pro.suspend_d(suspend_type='S', trade_date='20200312')
```

数据样例

```python
ts_code suspend_type trade_date suspend_timing
0   000029.SZ            S     20200312           None
```